/*
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.pua.prot.
 *
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.pua.prot.aggregations;

import de.bsvrz.pua.prot.util.ArithmeticOperation;
import de.bsvrz.pua.prot.util.ExpressionResult;
import de.bsvrz.pua.prot.util.ExpressionResult.ResultType;
import de.bsvrz.pua.prot.util.ResultValue;
import de.bsvrz.sys.funclib.debug.Debug;
import de.bsvrz.sys.funclib.losb.messages.ErrorMessage;

/**
 * Aggregationsklasse für Prüffall 3 Zahlen: wert1-wert2+wert3-wert4 Text: *** -&gt; gefunden, sonst : nicht gefunden bool: 1xwahr -&gt; wahr, sonst falsch
 *
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 * @version $Revision$ / $Date$ / ($Author$)
 */
public class AggregationTest implements Aggregation {

	private ResultValue _result = null;

	private boolean _add = false;

	/**
	 * Zahlen: wert1-wert2+wert3-wert4 Text: *** -&gt; gefunden, sonst : nicht gefunden bool: 1xwahr -&gt; wahr, sonst falsch
	 *
	 * @see de.bsvrz.pua.prot.aggregations.Aggregation#aggregate(de.bsvrz.pua.prot.util.ResultValue)
	 */
	public void aggregate(ResultValue value) throws UnsupportedOperationException {
		if(_result == null) {
			try {
				_result = value.cloneForAggregation();
			}
			catch(CloneNotSupportedException e) {
				Debug.getLogger().error("Fehler beim Kopieren des Objekts: ", e);
			}
		}
		else {
			traverse(_result, value);
		}
	}

	/**
	 * Durchläuft die Werte und berechnet die Aggregation. Ergebnis wird im linken Operand abgelegt.
	 *
	 * @param left  Linker Operand. Wird geändert.
	 * @param right Rechter Operand. Wird nicht geändert.
	 */
	private void traverse(ResultValue left, ResultValue right) {
		if(left.isAtomar()) {
			if(!right.isAtomar()) {
				left.set(ExpressionResult.error());
			}
			else {
				//Wenn auf der linken Seite kein Wert vorliegt, dann einfach den Wert der rechten Seite verwenden
				if(left.getValue().getType() == ResultType.NONE) {
					left.set(right.getValue());
				}
				else if(left.getValue().getType() == right.getValue().getType()) {
					if(left.getValue().isArithmetic()) {
						if(right.isSummable())	//Wert nur aggregieren, falls innerhalb des Wertebereiches (siehe TAnf S.22)
						{
							ArithmeticOperation ao = new ArithmeticOperation(left.getValue());
							ao.set(right.getValue());
							if(_add) {
								left.set(ao.performPlusOperation());
							}
							else {
								left.set(ao.performMinusOperation());
							}
						}
					}
					else if(left.getValue().getType() == ResultType.STRING) {
						//left wird jedes Mal überprüft, könnte optimiert werden
						if(left.getValue().getString().contains("***") || right.getValue().getString().contains("***")) {
							left.getValue().set("gefunden");
						}
						else {
							left.getValue().set("nicht gefunden");
						}
					}
					else if(left.getValue().getType() != ResultType.BOOL) {
						if(left.getValue().getBool() || right.getValue().getBool()) {
							left.getValue().set(true);
						}
						else {
							left.getValue().set(false);
						}
					}
					// Fehler werfen, falls der Typ werder arithmetisch noch bool noch text ist. Text & Bool wird in getValue gesetzt!
					// sonst Fehler werfen!
					else {
						throw new UnsupportedOperationException(ErrorMessage.INCOMPATIBLE_TYPES + left.getValue().getType());
					}
				}
				else {
					left.set(ExpressionResult.error());
				}
			}
		}
		else {
			//Es werden soviele Feldelemente wie möglich aggregiert. Werte, für die es
			//keinen Partner gibt, werden verworfen.
			if(left.getChildren().size() > right.getChildren().size()) {
				left.truncChildren(right.getChildren().size());
			}
			for(int i = 0; i < left.getChildren().size(); i++) {
				traverse(left.getChildren().get(i), right.getChildren().get(i));
			}
		}
	}

	/** @see de.bsvrz.pua.prot.aggregations.Aggregation#getResult() */
	public ResultValue getResult() throws UnsupportedOperationException {
		ResultValue temp = _result;
		_result = null;
		return temp;
	}

	/** @see de.bsvrz.pua.prot.aggregations.Aggregation#getAggregationName() */
	public String getAggregationName() {
		return "TestAggregation";
	}
}
