/*
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.pua.prot.
 *
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.pua.prot.functions;

import antlr.collections.AST;
import de.bsvrz.pua.prot.exceptions.SemanticErrorException;
import de.bsvrz.pua.prot.processing.util.BaseDataSet;
import de.bsvrz.pua.prot.processing.util.ExpressionResultAndState;
import de.bsvrz.pua.prot.processing.util.TempAttribut;
import de.bsvrz.pua.prot.util.ErrorMessageBuilder;
import de.bsvrz.pua.prot.util.ExpressionResult;
import de.bsvrz.pua.prot.util.ExpressionResult.ResultType;
import de.bsvrz.pua.prot.util.ExpressionTree;
import de.bsvrz.pua.prot.util.attributes.RealElement;
import de.bsvrz.pua.prot.util.attributes.TempAttributeDescription;

import java.util.*;


/**
 * Berechnet die Potenz von zwei Operanden. Verwendet die von Java zur Verfügung gestellte Math.pow() Methode. Da immer double Werten gerechnet wird, kann
 * 'long' Genauigkeit nicht garantiert werden.
 *
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 * @version $Revision$ / $Date$ / ($Author$)
 */
public class Power implements ExpressionInterface {

	public ExpressionResult evaluate(
			List<ExpressionTree> expressionList,
			Hashtable<RealElement, BaseDataSet> realElements,
			Hashtable<TempAttributeDescription, TempAttribut> tempElements, final int pseudoObjectIndex) {
		if(expressionList == null || expressionList.size() != 2) {
			return ExpressionResult.error(ErrorMessageBuilder.illegalArgumentCount(this, expressionList, false, ErrorMessageBuilder.NUMERIC, ErrorMessageBuilder.NUMERIC));
		}
		else {
			ExpressionResult result = new ExpressionResult();

			ExpressionTree baseTree = expressionList.get(0);
			ExpressionTree exponentTree = expressionList.get(1);

			ExpressionResultAndState baseValue = baseTree.evaluateEx(realElements, tempElements, pseudoObjectIndex);
			ExpressionResultAndState expValue = exponentTree.evaluateEx(realElements, tempElements, pseudoObjectIndex);

			double base, exp;
			if(baseValue.getType() == ResultType.LONG || baseValue.getType() == ResultType.DOUBLE) {
				base = baseValue.getResult().getDouble();
			}
			else {
				return ExpressionResult.error(ErrorMessageBuilder.illegalArgument(this, expressionList, 0, baseValue, ErrorMessageBuilder.NUMERIC));			
			}

			if(expValue.getType() == ResultType.LONG || expValue.getType() == ResultType.DOUBLE) {
				exp = expValue.getResult().getDouble();
			}
			else {
				return ExpressionResult.error(ErrorMessageBuilder.illegalArgument(this, expressionList, 1, baseValue, ErrorMessageBuilder.NUMERIC));						
			}

			result.set(Math.pow(base, exp));

			return result;
		}
	}

	public ResultType getResultType(final List<ExpressionTree> expressionList, final AST ast) throws SemanticErrorException {
		if(expressionList == null || expressionList.size() != 2) return ResultType.ERROR;
		ExpressionTree baseTree = expressionList.get(0);
		ExpressionTree exponentTree = expressionList.get(1);
		final ResultType baseType = baseTree.getResultType(ast);
		final ResultType expType = exponentTree.getResultType(ast);
		if((baseType == ResultType.DOUBLE || baseType == ResultType.LONG) && (expType == ResultType.DOUBLE || expType == ResultType.LONG)) return ResultType.DOUBLE;
		return ResultType.ERROR;
	}

	@Override
	public String getFunctionName() {
		return "potenz";
	}
}
