// $ANTLR 2.7.7 (2006-11-01): "grammar.g" -> "ProtocolParser.java"$

/*
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.pua.prot.
 *
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */
	package de.bsvrz.pua.prot.interpreter;

	import java.io.*;
	import java.awt.event.*;
	import antlr.*;
	import antlr.debug.misc.*;

	import java.util.ArrayList;
	import java.util.HashSet;
	import java.util.List;
	import de.bsvrz.pua.prot.util.ExpressionTree;
	import de.bsvrz.pua.prot.util.ExpressionLeaf;
	import de.bsvrz.pua.prot.exceptions.CriticalParserException;
	import de.bsvrz.pua.prot.exceptions.SemanticErrorException;
	import de.bsvrz.pua.prot.util.ProcessingInformation;
	import de.bsvrz.pua.prot.util.ProcessingParameter;
	import de.bsvrz.sys.funclib.losb.datk.ProtocolType;
	import de.bsvrz.sys.funclib.losb.datk.NoChangeMarker;
	import de.bsvrz.pua.prot.util.attributes.DurationAttributeDescription;

	import de.bsvrz.pua.prot.interpreter.semantics.Semantics;
	import de.bsvrz.pua.prot.interpreter.semantics.AggregationSemantics;
	import de.bsvrz.pua.prot.interpreter.semantics.AttributeGroupSemantics;
	import de.bsvrz.pua.prot.interpreter.semantics.AttributeSemantics;
	import de.bsvrz.pua.prot.interpreter.semantics.ExpressionSemantics;
	import de.bsvrz.pua.prot.interpreter.semantics.MiscellaneousSemantics;
	import de.bsvrz.pua.prot.interpreter.semantics.RealAttributeSemantics;
	import de.bsvrz.pua.prot.interpreter.semantics.ScopeSemantics;
	import de.bsvrz.pua.prot.interpreter.semantics.TempAttributeSemantics;
	import de.bsvrz.pua.prot.interpreter.semantics.SymbolTable;

	import de.bsvrz.dav.daf.main.config.DataModel;


public interface ProtocolLexerTokenTypes {
	int EOF = 1;
	int NULL_TREE_LOOKAHEAD = 3;
	int Spalten = 4;
	int Doppelpunkt = 5;
	int Mit = 6;
	int Ende = 7;
	int Name = 8;
	int NameMitKlammern = 9;
	int Fragezeichen = 10;
	int GanzZahl = 11;
	int Attribut = 12;
	int Zeitdauer = 13;
	int Als = 14;
	int Zeichenkette = 15;
	int TempAttribut = 16;
	int Attributgruppe = 17;
	int Filter = 18;
	int Aggregation = 19;
	int Komma = 20;
	int Einschraenkung = 21;
	int EinschraenkungUml = 22;
	int Verschmelzen = 23;
	int Anwendung = 24;
	int Gesamt = 25;
	int KlammerAuf = 26;
	int Objekt = 27;
	int Spalte = 28;
	int KlammerZu = 29;
	int Intervall = 30;
	int Liste = 31;
	int Nachfilter = 32;
	int Standards = 33;
	int Protokollzeitraum = 34;
	int Datum = 35;
	int Zeit = 36;
	int Minus = 37;
	int Protokollart = 38;
	int Aenderungsprotokoll = 39;
	int AenderungsprotokollUml = 40;
	int Zustandsprotokoll = 41;
	int Ereignisprotokoll = 42;
	int Gleich = 43;
	int UnveraendertKennungA = 44;
	int Pro = 45;
	int Zeile = 46;
	int Zelle = 47;
	int UnveraendertKennungB = 48;
	int Pseudoobjekt = 49;
	int Definitionen = 50;
	int Aggregationsfunktion = 51;
	int Alias = 52;
	int Oder = 53;
	int Und = 54;
	int Ungleich = 55;
	int Kleiner = 56;
	int Groesser = 57;
	int KleinerGleich = 58;
	int GroesserGleich = 59;
	int Plus = 60;
	int Ampersand = 61;
	int Mal = 62;
	int Dividiert = 63;
	int Div = 64;
	int Modulo = 65;
	int Nicht = 66;
	int KommaZahl = 67;
	int EckigeKlammerAuf = 68;
	int EckigeKlammerZu = 69;
	int Potenz = 70;
	int Exp = 71;
	int Ln = 72;
	int Min = 73;
	int Max = 74;
	int Abs = 75;
	int IstFehler = 76;
	int IstZahl = 77;
	int IstZustand = 78;
	int IstLeer = 79;
	int IstText = 80;
	int IstWahrheitswert = 81;
	int Falsch = 82;
	int Wahr = 83;
	int NichtAuffuellenA = 84;
	int NichtAuffuellenB = 85;
	int Prozent = 86;
	int Punkt = 87;
	int NameOderNameMitKlammern = 88;
	int SL_COMMENT = 89;
	int DatumOderZahl = 90;
	int Ziffer = 91;
	int Steuerungszeichen = 92;
	int WS = 93;
	int ZeilenEnde = 94;
	int Umlaut = 95;
}
