/*
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.pua.prot.
 *
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.pua.prot.util;


/**
 * Klasse zum Zugriff auf Ergebnisse von Methodenaufrufen im Segment Protokolle und Auswertungen. ACHTUNG: Werden Änderungen an diesem Interface durchgeführt,
 * so sind diese ebenfalls im Feinentwurf zu Segement 09 - PuA zu berücksichtigen!
 *
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 * @version $Revision$ / $Date$ / ($Author$)
 */
public class ProtocolRequestResult {

	/** Gibt an, ob die Operation fehlerfrei durchgeführt werden konnte */
	private boolean _successful;

	/** Fehlermeldung */
	private String _errorMsg;

	/** Erzeugt eine positive Quittung. */
	public ProtocolRequestResult() {
		_successful = true;
		_errorMsg = "";
	}

	/**
	 * Erzeugt eine negative Quittung.
	 *
	 * @param errorMsg Fehlermeldung.
	 */
	public ProtocolRequestResult(String errorMsg) {
		_successful = false;

		if(errorMsg != null) {
			this._errorMsg = errorMsg;
		}
		else {
			this._errorMsg = "";
		}
	}

	/**
	 * Erzeugt eine negative Quittung. Entspricht <code>this(cause.getMessage());</code>
	 *
	 * @param cause Fehlermeldung.
	 */
	public ProtocolRequestResult(Throwable cause) {
		this((cause.getMessage() != null && !cause.getMessage().equals("")) ? cause.getMessage() : de.bsvrz.sys.funclib.losb.util.Util.getStackTrace(cause));
	}

	/**
	 * Gibt an ob die Anfrage erfolgreich abgesetzt oder durchgeführt werden konnte
	 *
	 * @return true falls die Anfrage erfolgreich abgesetzt wurde. False sonst.
	 */
	public boolean isRequestSuccessful() {
		return _successful;
	}

	/** @return Liefert eine Fehlermeldung zurück, falls es zu einem Fehler kam. */
	public String getErrorMsg() {
		return _errorMsg;
	}

	/** @see java.lang.Object#toString() */
	@Override
    public String toString() {
		if(_successful) {
			return "ok";
		}
		else {
			return _errorMsg;
		}
	}

	/**
	 * Kopiert die Werte des Parameters in das Objekt.
	 *
	 * @param other Objekt, dessen Wert übernommen wird.
	 */
	public void set(ProtocolRequestResult other) {
		if(other != null) {
			this._errorMsg = other._errorMsg;
			this._successful = other._successful;
		}
	}

	/**
	 * Erzeugt eine negative Quittung.
	 *
	 * @param errorMsg Fehlermeldung
	 */
	public void set(String errorMsg) {
		this._successful = false;
		this._errorMsg = errorMsg;
	}

	/** Operation war erfolgreich. */
	public void setSuccessful() {
		_errorMsg = null;
		_successful = true;
	}
}
