/*
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.pua.prot.
 *
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.pua.prot.client.dataobject;

import de.bsvrz.dav.daf.main.config.DataModel;
import de.bsvrz.pua.prot.data.ProtocolData;
import de.bsvrz.pua.prot.util.ProcessingInformation.ApplyAggregation;
import de.bsvrz.sys.funclib.losb.util.Util;

/**
 * Wird beim Erstellung eines Zustandsprotokolls gesendet, wenn sich die Daten nicht geändert haben.
 *
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 * @version $Revision$ / $Date$ / ($Author$)
 */
public class ProtocolNoChanges implements ProtocolResult {

	private static final long serialVersionUID = 5154976570746301727L;

	/** Zeitstempel. */
	public long timestamp;

	/** Aggregation, die diesen Datensatz erzeugt hat. */
	public final ApplyAggregation order;

	/**
	 * @param timestamp Zeitstempel.
	 * @param order     Aggregation, die diesen Datensatz erzeugt hat.
	 */
	public ProtocolNoChanges(long timestamp, ApplyAggregation order) {
		this.timestamp = timestamp;
		this.order = order;
	}

	/** @see java.lang.Object#toString() */
	@Override
    public String toString() {
		StringBuffer sb = new StringBuffer("EDS ");
		Util.msToDate(sb, timestamp);
		sb.append(" (" + timestamp + ")\tKeine Änderung.");
		return sb.toString();
	}


	@Override
	public String toString(final DataModel dataModel) {
		StringBuilder sb = new StringBuilder();
		//nicht aufgefüllten Zeitstempel ausgeben (-> ist immer der größte Zeitstempel)
		long maxTime = getTimeStamp();

		sb.append(String.format("%-28s", "  " + Util.msToDate(maxTime) + ":"));

		sb.append("Keine Änderungen");
		return sb.toString();
	}

	/** @see java.lang.Object#equals(java.lang.Object) */
	@Override
    public boolean equals(Object object) {
		if(object == null) {
			return false;
		}
		else if(object instanceof ProtocolNoChanges) {
			ProtocolNoChanges other = (ProtocolNoChanges)object;
			return other.timestamp == this.timestamp;
		}
		else {
			return false;
		}
	}

	/** @see de.bsvrz.pua.prot.client.dataobject.ProtocolResult#getType() */
	public int getType() {
		return ProtocolResult.NO_CHANGE_DATA;
	}


	/**
	 * Liefert den Zeitstempel zurück.
	 *
	 * @return Zeitstempel.
	 */
	public long getTimeStamp() {
		return timestamp;
	}
}
