/*
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.pua.prot.
 *
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.pua.prot.client.dataobject;

import de.bsvrz.dav.daf.main.config.DataModel;

import java.io.Serializable;

/**
 * Datensatz der von dem Segment Protokolle und Auswertungen an den Aufrufer zurückgesendet wird.
 *
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 * @version $Revision$ / $Date$ / ($Author$)
 */
public interface ProtocolResult extends Serializable {

	/**
	 * Kennung des Administrationsdatensatzes.
	 *
	 * @see #getType()
	 */
	public static final int ADMINISTRATION_DATA = 1;

	/**
	 * Kennung des Aggregationsdatensatzes, der anzeigt, welche Aggregationen verwendet wurden.
	 *
	 * @see #getType()
	 */
	public static final int AGGREGATION_DATA = 2;

	/**
	 * Kennung eines Datensatzes.
	 *
	 * @see #getType()
	 */
	public static final int PROTOCOL_DATA = 4;

	/**
	 * Kennung eines Datensatzes, der dem zuletzt gesendetem entspricht.
	 *
	 * @see #getType()
	 */
	public static final int NO_CHANGE_DATA = 8;

	/**
	 * Kennung eines Datensatzes, der Aggregationsergebnisse enthält.
	 *
	 * @see #getType()
	 */
	public static final int AGGREGATION_RESULT_DATA = 16;

	/**
	 * Liefert den Typ des Datensatzes zurück.
	 *
	 * @return Liefert je nach Datensatz {@link #ADMINISTRATION_DATA},{@link #AGGREGATION_DATA},{@link #PROTOCOL_DATA},{@link #NO_CHANGE_DATA},{@link #AGGREGATION_RESULT_DATA}
	 */
	public int getType();

	/** Im Gegensatz zu toString() verbesserte Ausgabe 
	 * @param dataModel Datenmodell zur Abfrage von Objektinfos
	 * @return toString-Ausgabe
	 */
	String toString(DataModel dataModel);
}
