/*
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.pua.prot.
 *
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.pua.prot.functions;

import antlr.collections.AST;
import de.bsvrz.pua.prot.exceptions.SemanticErrorException;
import de.bsvrz.pua.prot.processing.util.BaseDataSet;
import de.bsvrz.pua.prot.processing.util.TempAttribut;
import de.bsvrz.pua.prot.util.ExpressionResult;
import de.bsvrz.pua.prot.util.ExpressionTree;
import de.bsvrz.pua.prot.util.attributes.RealElement;
import de.bsvrz.pua.prot.util.attributes.TempAttributeDescription;

import java.util.*;


/**
 * Basisinterface für die Funktionen, die in einem Ausdruck vorkommen können.
 *
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 * @version $Revision$ / $Date$ / ($Author$)
 */
public interface ExpressionInterface {

	/**
	 * Berechnet das Ergebnis der Funktion
	 *
	 * @param expressionList Liste mit den Eingabeparametern
	 * @param realElements   Mapping der realen Elemente zu den ihnen zugeordeten Werten.
	 * @param tempElements   Mapping der temporären Attribute zu den ihnen zugeordneten Werten.
	 *
	 * @param pseudoObjectIndex PseudoObjectIndex
	 * @return Ergebnis
	 */
	public ExpressionResult evaluate(
			List<ExpressionTree> expressionList,
			Hashtable<RealElement, BaseDataSet> realElements,
			Hashtable<TempAttributeDescription, TempAttribut> tempElements, 
			final int pseudoObjectIndex);

	/**
	 * Ermittelt den Ergebnistyp.
	 * @param expressionList Liste mit den Eingabeparametern
	 * @param ast Abstrakter Syntaxbaum des Parsers mit Informationen wie Zeilennummern für Fehlerausgaben
	 * @return `BOOL`, falls genau ein Argument angegeben wurde; ansonsten `ResultType.ERROR`
	 * @throws SemanticErrorException Exception
	 */
	public ExpressionResult.ResultType getResultType(List<ExpressionTree> expressionList, final AST ast) throws SemanticErrorException;

	/**
	 * Liefert den Namen der Funktion.
	 * Die Methode sollte von einer Implementierung überschrieben werden und den im Skript verwendeten Namen der Funktion zurückliefern.
	 * Die Default-Implementierung liefert den Namen der Klasse, die die Funktion implementiert.
	 * @return Name der Funktion
	 */
	public default String getFunctionName() {
		return getClass().getSimpleName();
	}
}
