/*
 * Copyright 2019 by Kappich Systemberatung Aachen
 *
 * This file is part of de.bsvrz.pua.prot.
 *
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.pua.prot.manager.taskmanager;

import de.bsvrz.dav.daf.main.ClientDavInterface;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.pua.prot.manager.datamanager.DataManagerInterface;
import de.bsvrz.pua.prot.processing.ProcessingInterface;
import de.bsvrz.pua.prot.processing.ProtocolReader;
import de.bsvrz.pua.prot.sender.PuaSender;
import de.bsvrz.sys.funclib.losb.exceptions.FailureException;

/**
 * Klasse, die ungelesene Protokolle liest
 * 
 * @author Kappich Systemberatung
 */
public class GetUnreadProtocolTask extends AbstractTask {

	/**
	 * @param dav                Verbindung zum Datenverteiler.
	 * @param client             Auftraggeber.
	 * @param requestId          Anfrage-ID
	 * @param protocolId         Id des Protokolls, das gesendet werden soll.
	 * @param jobId              JobId
	 * @param startTime          StartTime
	 * @param initialFlowControl InitialFlowControl
	 */
	public GetUnreadProtocolTask(final ClientDavInterface dav, final SystemObject client, final long requestId, final long protocolId, final long jobId, final long startTime, final long initialFlowControl) {
		super(dav, client, requestId, protocolId, jobId, startTime, initialFlowControl);
	}

	@Override
	public ThreadElement.Operation getOperation() {
		return ThreadElement.Operation.SEND_UNREAD_PROTOCOL;
	}

	@Override
	protected ProcessingInterface process(final DataManagerInterface dataManager, final ThreadElement threadElement, final PuaSender puaSender) throws FailureException {
		return new ProtocolReader(puaSender, threadElement.getSerializer(), getProtocolId(), threadElement.getMaxDelay(), threadElement.getTimeout(), dataManager, getJobId(), getInitialFlowControl());
	}

}
