/*
 * Copyright 2015 by Kappich Systemberatung Aachen
 *
 * This file is part of de.bsvrz.pua.prot.
 *
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.pua.prot.processing.util;

import de.bsvrz.pua.prot.client.dataobject.PuADataState;
import de.bsvrz.pua.prot.util.ExpressionResult;

/**
 * Ein ExpressionResult mit einem PuADataState kombiniert um einen Ergebniswert und Zustand abzubilden
 *
 * @author Kappich Systemberatung
 */
public class ExpressionResultAndState {
	
	private final ExpressionResult _result;
	
	private final PuADataState _state;

	public ExpressionResultAndState(final ExpressionResult result, final PuADataState state) {
		if(result == null) throw new IllegalArgumentException("result ist null");
		if(state == null) throw new IllegalArgumentException("state ist null");
		_result = result;
		_state = state;
	}

	public static ExpressionResultAndState error(final String error) {
		return new ExpressionResultAndState(ExpressionResult.error(error), PuADataState.ERROR);
	}

	public static ExpressionResultAndState deriveResult(final boolean result, final ExpressionResultAndState parameter) {
		return new ExpressionResultAndState(new ExpressionResult(result), parameter.getState());
	}
	
	public static ExpressionResultAndState deriveResult(final double result, final ExpressionResultAndState parameter) {
		return new ExpressionResultAndState(new ExpressionResult(result), parameter.getState());
	}
	
	public static ExpressionResultAndState deriveResult(final String result, final ExpressionResultAndState parameter) {
		return new ExpressionResultAndState(new ExpressionResult(result), parameter.getState());
	}

	public static ExpressionResultAndState noResult(final ExpressionResultAndState parameter) {
		return new ExpressionResultAndState(new ExpressionResult(), parameter.getState());
	}
	
	public static ExpressionResultAndState deriveResult(final boolean result, final ExpressionResultAndState parameterA, final ExpressionResultAndState parameterB) {
		return new ExpressionResultAndState(new ExpressionResult(result), getState(parameterA, parameterB));
	}
	
	public static ExpressionResultAndState deriveResult(final double result, final ExpressionResultAndState parameterA, final ExpressionResultAndState parameterB) {
		return new ExpressionResultAndState(new ExpressionResult(result), getState(parameterA, parameterB));
	}
	
	public static ExpressionResultAndState deriveResult(final String result, final ExpressionResultAndState parameterA, final ExpressionResultAndState parameterB) {
		return new ExpressionResultAndState(new ExpressionResult(result), getState(parameterA, parameterB));
	}

	public static ExpressionResultAndState noResult(final ExpressionResultAndState parameterA, final ExpressionResultAndState parameterB) {
		return new ExpressionResultAndState(new ExpressionResult(), getState(parameterA, parameterB));
	}

	public static PuADataState getState(final ExpressionResultAndState parameterA, final ExpressionResultAndState parameterB) {
		PuADataState a = parameterA.getState();
		PuADataState b = parameterB.getState();
		if(a.compareTo(b) > 0){
			return a;
		}
		else {
			return b;
		}
	}

	public ExpressionResult getResult() {
		return _result;
	}

	public PuADataState getState() {
		return _state;
	}

	public ExpressionResult.ResultType getType() {
		return _result.getType();
	}

	public static ExpressionResultAndState plain(final long value) {
		return new ExpressionResultAndState(new ExpressionResult(value), PuADataState.COMPUTED);
	}
	public static ExpressionResultAndState plain(final double value) {
		return new ExpressionResultAndState(new ExpressionResult(value), PuADataState.COMPUTED);
	}	
	public static ExpressionResultAndState plain(final String value) {
		return new ExpressionResultAndState(new ExpressionResult(value), PuADataState.COMPUTED);
	}
	public static ExpressionResultAndState plain(final boolean value) {
		return new ExpressionResultAndState(new ExpressionResult(value), PuADataState.COMPUTED);
	}

	@Override
	public String toString() {
		return _result.toString();
	}
}
